@@ -1,5 +1,5 @@
 #
-# $Id: Compare.pm,v 1.12 2005/03/01 09:05:33 dave Exp $
+# $Id: Compare.pm 28 2008-03-06 22:04:59Z dave $
 #
 
 =head1 NAME
@@ -41,7 +41,7 @@ this:
 
   my $comp = Array::Compare->new;
 
-  if ($comp->compare(\@arr1, \@arr2) {
+  if ($comp->compare(\@arr1, \@arr2)) {
     print "Arrays are the same\n";
   } else {
     print "Arrays are different\n";
@@ -178,12 +178,14 @@ but C<Skip> is ignored for, hopefully, obvious reasons.
 
 package Array::Compare;
 
+require 5.006_000;
 use strict;
-use vars qw($VERSION $AUTOLOAD);
+use warnings;
+our ($VERSION, $AUTOLOAD);
 
 use Carp;
 
-$VERSION = sprintf "%d.%02d", '$Revision: 1.12 $ ' =~ /(\d+)\.(\d+)/;
+$VERSION = 1.15;
 
 my %_defaults = (Sep => '^G',
 		 WhiteSpace => 1,
@@ -503,7 +505,10 @@ under the same terms as Perl itself.
 =cut
 
 #
-# $Log: Compare.pm,v $
+# $Log$
+# Revision 1.13  2005/09/21 09:23:40  dave
+# Documentation fix
+#
 # Revision 1.12  2005/03/01 09:05:33  dave
 # Changes to pass Pod::Coverage tests (and, hence, increase kwalitee)
 #
